#[repr(C)]pub struct __IncompleteArrayField<T>(PhantomData<T>, [T; 0]);Tuple Fields
0: PhantomData<T>1: [T; 0]Implementations
Sourceimpl<T> __IncompleteArrayField<T>
impl<T> __IncompleteArrayField<T>
pub fn new() -> Self
Sourcepub unsafe fn as_ptr(&self) -> *const T
pub unsafe fn as_ptr(&self) -> *const T
Safety
Caller must ensure that Self`s size, alignment and lifetime are compatible with returned values requirements.
Sourcepub unsafe fn as_mut_ptr(&mut self) -> *mut T
pub unsafe fn as_mut_ptr(&mut self) -> *mut T
Safety
Caller must ensure that Self`s size, alignment and lifetime are compatible with returned values requirements.
Sourcepub unsafe fn as_slice(&self, len: usize) -> &[T]
pub unsafe fn as_slice(&self, len: usize) -> &[T]
Safety
Caller must ensure that Self`s size, alignment and lifetime are compatible with returned values requirements.
Sourcepub unsafe fn as_mut_slice(&mut self, len: usize) -> &mut [T]
pub unsafe fn as_mut_slice(&mut self, len: usize) -> &mut [T]
Safety
Caller must ensure that Self`s size, alignment and lifetime are compatible with returned values requirements.