fn cpuid_ecx_bit_set(entries: &[CpuIdEntry], leaf: u32, shift: u32) -> boolExpand description
Whether any entry for leaf has the ecx bit at shift set.
fn cpuid_ecx_bit_set(entries: &[CpuIdEntry], leaf: u32, shift: u32) -> boolWhether any entry for leaf has the ecx bit at shift set.