fn nested_feature_available(
entries: &[CpuIdEntry],
manufacturer: CpuManufacturer,
) -> boolExpand description
Whether entries advertise the nested virtualization feature for the
host’s own vendor: VMX on Intel, SVM on AMD.
fn nested_feature_available(
entries: &[CpuIdEntry],
manufacturer: CpuManufacturer,
) -> boolWhether entries advertise the nested virtualization feature for the
host’s own vendor: VMX on Intel, SVM on AMD.