Struct CpuIdContext

pub struct CpuIdContext {
    vcpu_id: usize,
    vcpu_count: usize,
    x2apic: bool,
    tsc_deadline_timer: bool,
    apic_frequency: u32,
    tsc_frequency: Option<u64>,
    cpu_config: CpuConfigX86_64,
    cpuid_count: unsafe fn(u32, u32) -> CpuidResult,
    cpuid: unsafe fn(u32) -> CpuidResult,
}
All of the context required to emulate the CPUID instruction.

Fields

vcpu_id: usize

Id of the Vcpu associated with this context.

vcpu_count: usize

The total number of vcpus on this VM.

x2apic: bool

Whether or not the IrqChip’s APICs support X2APIC.

tsc_deadline_timer: bool

Whether or not the IrqChip’s APICs support a TSC deadline timer.

apic_frequency: u32

The frequency at which the IrqChip’s APICs run.

tsc_frequency: Option<u64>

The TSC frequency in Hz, if it could be determined.

cpu_config: CpuConfigX86_64

CPU feature configurations.

cpuid_count: unsafe fn(u32, u32) -> CpuidResult

__cpuid_count or a fake function for test.

cpuid: unsafe fn(u32) -> CpuidResult

__cpuid or a fake function for test.

Implementations

Source

impl CpuIdContext

pub fn new( vcpu_id: usize, vcpu_count: usize, irq_chip: Option<&dyn IrqChipX86_64>, cpu_config: CpuConfigX86_64, calibrated_tsc_leaf_required: bool, cpuid_count: unsafe fn(u32, u32) -> CpuidResult, cpuid: unsafe fn(u32) -> CpuidResult, ) -> CpuIdContext