Function create_fdt

pub fn create_fdt(
    guest_mem: &GuestMemory,
    android_fstab: Option<File>,
    dump_device_tree_blob: Option<PathBuf>,
    device_tree_overlays: Vec<DtbOverlay>,
    kernel_region: AddressRange,
    initrd: Option<(GuestAddress, u32)>,
) -> Result<Vec<u8>, Error>
Creates a flattened device tree containing all of the parameters for the kernel and returns it as DTB.

Arguments

  • android_fstab - the File object for the android fstab