Struct x86_64::msr::MsrDevFile
source · pub struct MsrDevFile {
dev_msr: File,
}Expand description
Wrap for userspace MSR file descriptor (/dev/cpu/*/msr).
Fields
dev_msr: FileImplementations
sourceimpl MsrDevFile
impl MsrDevFile
sourcefn new(cpu_id: usize, read_only: bool) -> Result<Self>
fn new(cpu_id: usize, read_only: bool) -> Result<Self>
Create a new MSR file descriptor.
“Passthrough” handler will create file descriptor with both read and write permissions. MsrHandlers controls read/write with MsrRWType. This avoids the corner case that some MSRs are read-only while other MSRs need write permission. “Emulate” handler will create read-only file descriptor. This read-only descriptor will only be used once to initialize MSR value and “Emulate” handler won’t store its descriptor at MsrHandlers level.
fn read(&self, index: u32) -> Result<u64>
fn write(&self, index: u32, data: u64) -> Result<()>