pub struct SetupDataEntries {
pub(crate) entries: Vec<SetupData>,
pub(crate) setup_data_start: usize,
pub(crate) setup_data_end: usize,
pub(crate) available_size: usize,
}Expand description
Collection of SetupData entries to be inserted in the
bootparam setup_data linked list.
Fields
entries: Vec<SetupData>setup_data_start: usizesetup_data_end: usizeavailable_size: usizeImplementations
Sourceimpl SetupDataEntries
impl SetupDataEntries
Sourcepub fn new(setup_data_start: usize, setup_data_end: usize) -> SetupDataEntries
pub fn new(setup_data_start: usize, setup_data_end: usize) -> SetupDataEntries
Returns a new instance of SetupDataEntries
Sourcepub fn insert(&mut self, setup_data: SetupData) -> usize
pub fn insert(&mut self, setup_data: SetupData) -> usize
Adds a new SetupDataEntry and returns the remaining size available
Sourcepub fn write_setup_data(
&self,
guest_mem: &GuestMemory,
) -> Result<Option<GuestAddress>>
pub fn write_setup_data( &self, guest_mem: &GuestMemory, ) -> Result<Option<GuestAddress>>
Copy setup_data entries to guest memory and link them together with the next field.
Returns the guest address of the first entry in the setup_data list, if any.