Struct x86_64::structures::idt::PageFaultErrorCode [−][src]
#[repr(transparent)]pub struct PageFaultErrorCode { /* fields omitted */ }
Describes an page fault error code.
Implementations
impl PageFaultErrorCode[src]
impl PageFaultErrorCode[src]pub const PROTECTION_VIOLATION: PageFaultErrorCode[src]
pub const PROTECTION_VIOLATION: PageFaultErrorCode[src]If this flag is set, the page fault was caused by a page-protection violation, else the page fault was caused by a not-present page.
pub const CAUSED_BY_WRITE: PageFaultErrorCode[src]
pub const CAUSED_BY_WRITE: PageFaultErrorCode[src]If this flag is set, the memory access that caused the page fault was a write. Else the access that caused the page fault is a memory read. This bit does not necessarily indicate the cause of the page fault was a read or write violation.
pub const USER_MODE: PageFaultErrorCode[src]
pub const USER_MODE: PageFaultErrorCode[src]If this flag is set, an access in user mode (CPL=3) caused the page fault. Else an access in supervisor mode (CPL=0, 1, or 2) caused the page fault. This bit does not necessarily indicate the cause of the page fault was a privilege violation.
pub const MALFORMED_TABLE: PageFaultErrorCode[src]
pub const MALFORMED_TABLE: PageFaultErrorCode[src]If this flag is set, the page fault is a result of the processor reading a 1 from a reserved field within a page-translation-table entry.
pub const INSTRUCTION_FETCH: PageFaultErrorCode[src]
pub const INSTRUCTION_FETCH: PageFaultErrorCode[src]If this flag is set, it indicates that the access that caused the page fault was an instruction fetch.
pub const fn empty() -> PageFaultErrorCode[src]
pub const fn empty() -> PageFaultErrorCode[src]Returns an empty set of flags
pub const fn all() -> PageFaultErrorCode[src]
pub const fn all() -> PageFaultErrorCode[src]Returns the set containing all flags.
pub fn from_bits(bits: u64) -> Option<PageFaultErrorCode>[src]
pub fn from_bits(bits: u64) -> Option<PageFaultErrorCode>[src]Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u64) -> PageFaultErrorCode[src]
pub const fn from_bits_truncate(bits: u64) -> PageFaultErrorCode[src]Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const unsafe fn from_bits_unchecked(bits: u64) -> PageFaultErrorCode[src]
pub const unsafe fn from_bits_unchecked(bits: u64) -> PageFaultErrorCode[src]Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
pub const fn intersects(&self, other: PageFaultErrorCode) -> bool[src]
pub const fn intersects(&self, other: PageFaultErrorCode) -> bool[src]Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: PageFaultErrorCode) -> bool[src]
pub const fn contains(&self, other: PageFaultErrorCode) -> bool[src]Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: PageFaultErrorCode)[src]
pub fn insert(&mut self, other: PageFaultErrorCode)[src]Inserts the specified flags in-place.
pub fn remove(&mut self, other: PageFaultErrorCode)[src]
pub fn remove(&mut self, other: PageFaultErrorCode)[src]Removes the specified flags in-place.
pub fn toggle(&mut self, other: PageFaultErrorCode)[src]
pub fn toggle(&mut self, other: PageFaultErrorCode)[src]Toggles the specified flags in-place.
pub fn set(&mut self, other: PageFaultErrorCode, value: bool)[src]
pub fn set(&mut self, other: PageFaultErrorCode, value: bool)[src]Inserts or removes the specified flags depending on the passed value.